/*
Most bonuses have the Type "LinearScaleFromDefaultHandicap" so that they scale by difficulty.
The actual bonus the AI will get at a specific difficulty is Value+Extra*Difficulty, with Difficulty being the number assigned to each difficulty.
Prince has the number 1, King 2... until Insane at 7.
The Value is usually 0.
*/

-- delete builders from bonus ai starting units
DELETE FROM MajorStartingUnits WHERE Unit='UNIT_BUILDER' AND AiOnly=1;

-- add scouts to starting units
INSERT INTO MajorStartingUnits (Unit, Era, District, Quantity, NotStartTile, OnDistrictCreated, AiOnly, MinDifficulty, DifficultyDelta)
VALUES ('UNIT_SCOUT', 'ERA_ANCIENT', 'DISTRICT_CITY_CENTER', 1, 0, 1, 1, 'DIFFICULTY_EMPEROR', 0.5);

-- remove barbarian camp gold scaling
UPDATE ModifierArguments SET Extra=0 WHERE Name='Amount' AND ModifierId='BARBARIAN_CAMP_GOLD_SCALING';

-- reduce flat gold and production per difficulty from 20% to 10%
UPDATE ModifierArguments SET Extra=10 WHERE Name='Amount' AND ModifierId='HIGH_DIFFICULTY_GOLD_SCALING';
UPDATE ModifierArguments SET Extra=10 WHERE Name='Amount' AND ModifierId='HIGH_DIFFICULTY_PRODUCTION_SCALING';

-- increase flat faith from 8% to 10% (I think faith should get the same bonus as gold and production)
UPDATE ModifierArguments SET Extra=10 WHERE Name='Amount' AND ModifierId='HIGH_DIFFICULTY_FAITH_SCALING';

-- remove flat science and culture bonus (was 8% per difficulty)
UPDATE ModifierArguments SET Extra=0 WHERE Name = 'Amount' AND ModifierId = 'HIGH_DIFFICULTY_SCIENCE_SCALING';
UPDATE ModifierArguments SET Extra=0 WHERE Name = 'Amount' AND ModifierId = 'HIGH_DIFFICULTY_CULTURE_SCALING';

-- add free eurekas and inspirations per era
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES	
('TRAIT_LEADER_MAJOR_CIV',	'HIGH_DIFFICULTY_FREE_TECH_BOOSTS'),
('TRAIT_LEADER_MAJOR_CIV',	'HIGH_DIFFICULTY_FREE_CIVIC_BOOSTS');

UPDATE ModifierArguments SET Extra=0.5 WHERE Name='Amount' AND ModifierId='HIGH_DIFFICULTY_FREE_TECH_BOOSTS';
UPDATE ModifierArguments SET Extra=0.5 WHERE Name='Amount' AND ModifierId='HIGH_DIFFICULTY_FREE_CIVIC_BOOSTS';

--loyalty modifier to help AI keep conquered cities
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_LOYALTY');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId, SubjectRequirementSetId) VALUES
('LGAI_LOYALTY', 'MODIFIER_PLAYER_CITIES_ADJUST_IDENTITY_PER_TURN', 'PLAYER_IS_HIGH_DIFFICULTY_AI', 'CITY_NOT_FOUNDED');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value, Extra) VALUES
('LGAI_LOYALTY', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 1);

-- Bonus economic slot for AI at Political Philosophy, bonus wildcard slot for AI at Ideology
INSERT INTO Modifiers (ModifierId, ModifierType, SubjectRequirementSetId, RunOnce, Permanent) VALUES
('LGAI_BONUS_ECONOMIC_GOVERNMENT_SLOT',	'MODIFIER_PLAYER_CULTURE_ADJUST_GOVERNMENT_SLOTS_MODIFIER',	'PLAYER_IS_HIGH_DIFFICULTY_AI',	0, 0),
('LGAI_BONUS_WILDCARD_GOVERNMENT_SLOT',	'MODIFIER_PLAYER_CULTURE_ADJUST_GOVERNMENT_SLOTS_MODIFIER',	'PLAYER_IS_HIGH_DIFFICULTY_AI',	0, 0);

INSERT INTO ModifierArguments (ModifierId, Name, Value) VALUES
('LGAI_BONUS_ECONOMIC_GOVERNMENT_SLOT',	'GovernmentSlotType',	'SLOT_ECONOMIC'),
('LGAI_BONUS_WILDCARD_GOVERNMENT_SLOT',	'GovernmentSlotType',	'SLOT_WILDCARD');

INSERT INTO CivicModifiers (CivicType, ModifierId) VALUES
('CIVIC_POLITICAL_PHILOSOPHY',	'LGAI_BONUS_ECONOMIC_GOVERNMENT_SLOT'),
('CIVIC_IDEOLOGY',		'LGAI_BONUS_WILDCARD_GOVERNMENT_SLOT');

-- add +2 builder movement
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_BUILDERMOVEMENT');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId, SubjectRequirementSetId) VALUES
('LGAI_BUILDERMOVEMENT', 'MODIFIER_PLAYER_UNITS_ADJUST_MOVEMENT', 'PLAYER_IS_HIGH_DIFFICULTY_AI', 'UNIT_IS_BUILDER');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value, Extra) VALUES
('LGAI_BUILDERMOVEMENT', 'Amount', 'LinearScaleFromDefaultHandicap', 2, 0);

-- add extra aluminium at offworld mission so the AI always does the projects
INSERT INTO TechnologyModifiers (TechnologyType, ModifierId) VALUES
('TECH_OFFWORLD_MISSION', 'LGAI_OFFWORLD_ALUMINIUM');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('LGAI_OFFWORLD_ALUMINIUM', 'MODIFIER_PLAYER_ADJUST_FREE_RESOURCE_IMPORT_EXTRACTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value) VALUES
('LGAI_OFFWORLD_ALUMINIUM', 'ResourceType', 'ARGTYPE_IDENTITY', 'RESOURCE_ALUMINUM'),
('LGAI_OFFWORLD_ALUMINIUM', 'Amount', 'ARGTYPE_IDENTITY', '50');

-- add bonus production for space race projects
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_SPACEPRODUCTION');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('LGAI_SPACEPRODUCTION', 'MODIFIER_PLAYER_CITIES_ADJUST_SPACE_RACE_PROJECTS_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value, Extra) VALUES
('LGAI_SPACEPRODUCTION', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 10);

-- clumsy fix for the AI often skipping science victory techs, just give them previous techs when they research a later one
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_NANOTECH');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('LGAI_NANOTECH', 'MODIFIER_PLAYER_GRANT_SPECIFIC_TECHNOLOGY', 'LGAI_AI_SMART_MATERIALS');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value) VALUES
('LGAI_NANOTECH', 'TechType', 'ARGTYPE_IDENTITY', 'TECH_NANOTECHNOLOGY');

INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_ROCKETRY');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('LGAI_ROCKETRY', 'MODIFIER_PLAYER_GRANT_SPECIFIC_TECHNOLOGY', 'LGAI_AI_NANOTECH');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value) VALUES
('LGAI_ROCKETRY', 'TechType', 'ARGTYPE_IDENTITY', 'TECH_ROCKETRY');

INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_SATELLITES');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('LGAI_SATELLITES', 'MODIFIER_PLAYER_GRANT_SPECIFIC_TECHNOLOGY', 'LGAI_AI_SMART_MATERIALS');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value) VALUES
('LGAI_SATELLITES', 'TechType', 'ARGTYPE_IDENTITY', 'TECH_SATELLITES');

INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_SMART_MATERIALS');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('LGAI_SMART_MATERIALS', 'MODIFIER_PLAYER_GRANT_SPECIFIC_TECHNOLOGY', 'LGAI_AI_OFFWORLD');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value) VALUES
('LGAI_SMART_MATERIALS', 'TechType', 'ARGTYPE_IDENTITY', 'TECH_SMART_MATERIALS');

-- +1 Influence point when AI reaches renaissance era and +2 Influence points when AI reaches atomic era per difficulty above Prince
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'INFLUENCEP_RENAISSANCE_KING');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('INFLUENCEP_RENAISSANCE_KING', 'MODIFIER_PLAYER_ADJUST_INFLUENCE_POINTS_PER_TURN', 'HIGH_DIFFICULTY_AI_RENAISSANCE_KING');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value, Extra) VALUES
('INFLUENCEP_RENAISSANCE_KING', 'Amount', 'LinearScaleFromDefaultHandicap', -1, 1);

INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'INFLUENCEP_ATOMIC_KING');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('INFLUENCEP_ATOMIC_KING', 'MODIFIER_PLAYER_ADJUST_INFLUENCE_POINTS_PER_TURN', 'HIGH_DIFFICULTY_AI_ATOMIC_KING');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value, Extra) VALUES
('INFLUENCEP_ATOMIC_KING', 'Amount', 'LinearScaleFromDefaultHandicap', -2, 2);

-- give AI 1 extra religious spread per second difficulty
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'RELIGIOUS_SPREADS_SCALING');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId, SubjectRequirementSetId, Permanent) VALUES
('RELIGIOUS_SPREADS_SCALING', 'MODIFIER_PLAYER_UNITS_RELIGIOUS_SPREADS', 'HIGH_DIFFICULTY_AI_EMPEROR', 'UNIT_IS_RELIGIOUS', 1);

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value, Extra) VALUES
('RELIGIOUS_SPREADS_SCALING', 'Amount', 'LinearScaleFromDefaultHandicap', -0.5, 0.5);

-- district project production penalty to make the AI not hog all the great people with their superior production
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_ENCAMPMENT'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_HARBOR'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_INDUSTRIAL_ZONE'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_COMMERCIAL_HUB'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_HOLY_SITE'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_CAMPUS'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_THEATER'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_CARNIVAL'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_WATER_CARNIVAL'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_CARBON_RECAPTURE'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_SEND_AID'),
('TRAIT_LEADER_MAJOR_CIV', 'LGAI_PROJECT_COURT_FESTIVAL');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('LGAI_PROJECT_ENCAMPMENT', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_HARBOR', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_INDUSTRIAL_ZONE', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_COMMERCIAL_HUB', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_HOLY_SITE', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_CAMPUS', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_THEATER', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_CARNIVAL', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_WATER_CARNIVAL', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_CARBON_RECAPTURE', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_SEND_AID', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI'),
('LGAI_PROJECT_COURT_FESTIVAL', 'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION', 'PLAYER_IS_HIGH_DIFFICULTY_AI');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value) VALUES
('LGAI_PROJECT_ENCAMPMENT', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_ENHANCE_DISTRICT_ENCAMPMENT'),
('LGAI_PROJECT_HARBOR', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_ENHANCE_DISTRICT_HARBOR'),
('LGAI_PROJECT_INDUSTRIAL_ZONE', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_ENHANCE_DISTRICT_INDUSTRIAL_ZONE'),
('LGAI_PROJECT_COMMERCIAL_HUB', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_ENHANCE_DISTRICT_COMMERCIAL_HUB'),
('LGAI_PROJECT_HOLY_SITE', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_ENHANCE_DISTRICT_HOLY_SITE'),
('LGAI_PROJECT_CAMPUS', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_ENHANCE_DISTRICT_CAMPUS'),
('LGAI_PROJECT_THEATER', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_ENHANCE_DISTRICT_THEATER'),
('LGAI_PROJECT_CARNIVAL', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_CARNIVAL'),
('LGAI_PROJECT_WATER_CARNIVAL', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_WATER_CARNIVAL'),
('LGAI_PROJECT_CARBON_RECAPTURE', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_CARBON_RECAPTURE'),
('LGAI_PROJECT_SEND_AID', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_SEND_AID'),
('LGAI_PROJECT_COURT_FESTIVAL', 'ProjectType', 'ARGTYPE_IDENTITY', 'PROJECT_COURT_FESTIVAL');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value, Extra) VALUES
('LGAI_PROJECT_ENCAMPMENT', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_HARBOR', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_INDUSTRIAL_ZONE', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_COMMERCIAL_HUB', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_HOLY_SITE', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_CAMPUS', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_THEATER', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_CARNIVAL', 'Amount', 'LinearScaleFromDefaultHandicap', -60, 0),
('LGAI_PROJECT_WATER_CARNIVAL', 'Amount', 'LinearScaleFromDefaultHandicap', -60, 0),
('LGAI_PROJECT_CARBON_RECAPTURE', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_SEND_AID', 'Amount', 'LinearScaleFromDefaultHandicap', -30, 0),
('LGAI_PROJECT_COURT_FESTIVAL', 'Amount', 'LinearScaleFromDefaultHandicap', -60, 0);

-- Additional boosts on Insane
INSERT INTO TraitModifiers (TraitType, ModifierId) VALUES	
('TRAIT_LEADER_MAJOR_CIV',	'LGAI_INSANE_FREE_TECH_BOOSTS'),
('TRAIT_LEADER_MAJOR_CIV',	'LGAI_INSANE_FREE_CIVIC_BOOSTS');

INSERT INTO Modifiers (ModifierId, ModifierType, OwnerRequirementSetId) VALUES
('LGAI_INSANE_FREE_TECH_BOOSTS', 'MODIFIER_PLAYER_GRANT_RANDOM_TECHNOLOGY_BOOST_ON_NEW_ERA', 'HIGH_DIFFICULTY_AI_INSANE'),
('LGAI_INSANE_FREE_CIVIC_BOOSTS', 'MODIFIER_PLAYER_GRANT_RANDOM_CIVIC_BOOST_ON_NEW_ERA', 'HIGH_DIFFICULTY_AI_INSANE');

INSERT INTO ModifierArguments (ModifierId, Name, Type, Value, Extra) VALUES
('LGAI_INSANE_FREE_TECH_BOOSTS', 'Amount', 'LinearScaleFromDefaultHandicap', 5, 0),
('LGAI_INSANE_FREE_TECH_BOOSTS', 'ApplyImmediately', 'ARGTYPE_IDENTITY', 1, NULL),
('LGAI_INSANE_FREE_CIVIC_BOOSTS', 'Amount', 'LinearScaleFromDefaultHandicap', 5, 0),
('LGAI_INSANE_FREE_CIVIC_BOOSTS', 'ApplyImmediately', 'ARGTYPE_IDENTITY', 1, NULL);

-- main scaling modifiers
-- if there is an _ERA at the end of the requirement, it means it scales with game era instead of player era.

INSERT INTO Modifiers 
		(ModifierId,						ModifierType,											OwnerRequirementSetId) 
VALUES		('AMENITY_SCALING_CLASSICAL', 'MODIFIER_PLAYER_CITIES_ADJUST_POLICY_AMENITY', 'HIGH_DIFFICULTY_AI_CLASSICAL'),
		('AMENITY_SCALING_MEDIEVAL', 'MODIFIER_PLAYER_CITIES_ADJUST_POLICY_AMENITY', 'HIGH_DIFFICULTY_AI_MEDIEVAL'),
		('AMENITY_SCALING_RENAISSANCE', 'MODIFIER_PLAYER_CITIES_ADJUST_POLICY_AMENITY', 'HIGH_DIFFICULTY_AI_RENAISSANCE'),
		('AMENITY_SCALING_INDUSTRIAL', 'MODIFIER_PLAYER_CITIES_ADJUST_POLICY_AMENITY', 'HIGH_DIFFICULTY_AI_INDUSTRIAL'),
		('AMENITY_SCALING_MODERN', 'MODIFIER_PLAYER_CITIES_ADJUST_POLICY_AMENITY', 'HIGH_DIFFICULTY_AI_MODERN'),
		('AMENITY_SCALING_ATOMIC', 'MODIFIER_PLAYER_CITIES_ADJUST_POLICY_AMENITY', 'HIGH_DIFFICULTY_AI_ATOMIC'),
		('AMENITY_SCALING_INFO', 'MODIFIER_PLAYER_CITIES_ADJUST_POLICY_AMENITY', 'HIGH_DIFFICULTY_AI_INFO'),
		('AMENITY_SCALING_FUTURE', 'MODIFIER_PLAYER_CITIES_ADJUST_POLICY_AMENITY', 'HIGH_DIFFICULTY_AI_FUTURE'),
		('TOURISM_SCALING_CLASSICAL', 'MODIFIER_PLAYER_ADJUST_TOURISM', 'HIGH_DIFFICULTY_AI_CLASSICAL_ERA'),
		('TOURISM_SCALING_MEDIEVAL', 'MODIFIER_PLAYER_ADJUST_TOURISM', 'HIGH_DIFFICULTY_AI_MEDIEVAL_ERA'),
		('TOURISM_SCALING_RENAISSANCE', 'MODIFIER_PLAYER_ADJUST_TOURISM', 'HIGH_DIFFICULTY_AI_RENAISSANCE_ERA'),
		('TOURISM_SCALING_INDUSTRIAL', 'MODIFIER_PLAYER_ADJUST_TOURISM', 'HIGH_DIFFICULTY_AI_INDUSTRIAL_ERA'),
		('TOURISM_SCALING_MODERN', 'MODIFIER_PLAYER_ADJUST_TOURISM', 'HIGH_DIFFICULTY_AI_MODERN_ERA'),
		('TOURISM_SCALING_ATOMIC', 'MODIFIER_PLAYER_ADJUST_TOURISM', 'HIGH_DIFFICULTY_AI_ATOMIC_ERA'),
		('TOURISM_SCALING_INFO', 'MODIFIER_PLAYER_ADJUST_TOURISM', 'HIGH_DIFFICULTY_AI_INFO_ERA'),
		('TOURISM_SCALING_FUTURE', 'MODIFIER_PLAYER_ADJUST_TOURISM', 'HIGH_DIFFICULTY_AI_FUTURE_ERA'),
		('SCIENCE_SCALING_CLASSICAL',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_CLASSICAL_ERA'),
		('SCIENCE_SCALING_MEDIEVAL',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MEDIEVAL_ERA'),
		('SCIENCE_SCALING_RENAISSANCE',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_RENAISSANCE_ERA'),
		('SCIENCE_SCALING_INDUSTRIAL',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INDUSTRIAL_ERA'),
		('SCIENCE_SCALING_MODERN',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MODERN_ERA'),
		('SCIENCE_SCALING_ATOMIC',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_ATOMIC_ERA'),
		('SCIENCE_SCALING_INFO',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INFO_ERA'),
		('SCIENCE_SCALING_FUTURE',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_FUTURE_ERA'),
		('CULTURE_SCALING_CLASSICAL',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_CLASSICAL_ERA'),
		('CULTURE_SCALING_MEDIEVAL',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MEDIEVAL_ERA'),
		('CULTURE_SCALING_RENAISSANCE',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_RENAISSANCE_ERA'),
		('CULTURE_SCALING_INDUSTRIAL',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INDUSTRIAL_ERA'),
		('CULTURE_SCALING_MODERN',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MODERN_ERA'),
		('CULTURE_SCALING_ATOMIC',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_ATOMIC_ERA'),
		('CULTURE_SCALING_INFO',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INFO_ERA'),
		('CULTURE_SCALING_FUTURE',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_FUTURE_ERA'),
		('FAITH_SCALING_CLASSICAL',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_CLASSICAL'),
		('FAITH_SCALING_MEDIEVAL',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MEDIEVAL'),
		('FAITH_SCALING_RENAISSANCE',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_RENAISSANCE'),
		('FAITH_SCALING_INDUSTRIAL',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INDUSTRIAL'),
		('FAITH_SCALING_MODERN',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MODERN'),
		('FAITH_SCALING_ATOMIC',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_ATOMIC'),
		('FAITH_SCALING_INFO',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INFO'),
		('FAITH_SCALING_FUTURE',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_FUTURE'),
		('PRODUCTION_SCALING_CLASSICAL',	'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_CLASSICAL'),
		('PRODUCTION_SCALING_MEDIEVAL',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MEDIEVAL'),
		('PRODUCTION_SCALING_RENAISSANCE',	'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_RENAISSANCE'),
		('PRODUCTION_SCALING_INDUSTRIAL',	'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INDUSTRIAL'),
		('PRODUCTION_SCALING_MODERN',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MODERN'),
		('PRODUCTION_SCALING_ATOMIC',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_ATOMIC'),
		('PRODUCTION_SCALING_INFO',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INFO'),
		('PRODUCTION_SCALING_FUTURE',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_FUTURE'),
		('GOLD_SCALING_CLASSICAL',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_CLASSICAL'),
		('GOLD_SCALING_MEDIEVAL',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MEDIEVAL'),
		('GOLD_SCALING_RENAISSANCE',		'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_RENAISSANCE'),
		('GOLD_SCALING_INDUSTRIAL',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INDUSTRIAL'),
		('GOLD_SCALING_MODERN',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MODERN'),
		('GOLD_SCALING_ATOMIC',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_ATOMIC'),
		('GOLD_SCALING_INFO',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INFO'),
		('GOLD_SCALING_FUTURE',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_FUTURE'),
		('FOOD_SCALING_CLASSICAL',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_CLASSICAL_ERA'),
		('FOOD_SCALING_MEDIEVAL',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MEDIEVAL_ERA'),
		('FOOD_SCALING_RENAISSANCE',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_RENAISSANCE_ERA'),
		('FOOD_SCALING_INDUSTRIAL',			'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INDUSTRIAL_ERA'),
		('FOOD_SCALING_MODERN',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_MODERN_ERA'),
		('FOOD_SCALING_ATOMIC',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_ATOMIC_ERA'),
		('FOOD_SCALING_INFO',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_INFO_ERA'),
		('FOOD_SCALING_FUTURE',				'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER',	'HIGH_DIFFICULTY_AI_FUTURE_ERA');

INSERT INTO TraitModifiers 
		(TraitType,						ModifierId) 
VALUES		('TRAIT_LEADER_MAJOR_CIV',		'AMENITY_SCALING_CLASSICAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'AMENITY_SCALING_MEDIEVAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'AMENITY_SCALING_RENAISSANCE'),
		('TRAIT_LEADER_MAJOR_CIV',		'AMENITY_SCALING_INDUSTRIAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'AMENITY_SCALING_MODERN'),
		('TRAIT_LEADER_MAJOR_CIV',		'AMENITY_SCALING_ATOMIC'),
		('TRAIT_LEADER_MAJOR_CIV',		'AMENITY_SCALING_INFO'),
		('TRAIT_LEADER_MAJOR_CIV',		'AMENITY_SCALING_FUTURE'),
		('TRAIT_LEADER_MAJOR_CIV',		'TOURISM_SCALING_CLASSICAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'TOURISM_SCALING_MEDIEVAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'TOURISM_SCALING_RENAISSANCE'),
		('TRAIT_LEADER_MAJOR_CIV',		'TOURISM_SCALING_INDUSTRIAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'TOURISM_SCALING_MODERN'),
		('TRAIT_LEADER_MAJOR_CIV',		'TOURISM_SCALING_ATOMIC'),
		('TRAIT_LEADER_MAJOR_CIV',		'TOURISM_SCALING_INFO'),
		('TRAIT_LEADER_MAJOR_CIV',		'TOURISM_SCALING_FUTURE'),
		('TRAIT_LEADER_MAJOR_CIV',		'SCIENCE_SCALING_CLASSICAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'SCIENCE_SCALING_MEDIEVAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'SCIENCE_SCALING_RENAISSANCE'),
		('TRAIT_LEADER_MAJOR_CIV',		'SCIENCE_SCALING_INDUSTRIAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'SCIENCE_SCALING_MODERN'),
		('TRAIT_LEADER_MAJOR_CIV',		'SCIENCE_SCALING_ATOMIC'),
		('TRAIT_LEADER_MAJOR_CIV',		'SCIENCE_SCALING_INFO'),
		('TRAIT_LEADER_MAJOR_CIV',		'SCIENCE_SCALING_FUTURE'),
		('TRAIT_LEADER_MAJOR_CIV',		'CULTURE_SCALING_CLASSICAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'CULTURE_SCALING_MEDIEVAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'CULTURE_SCALING_RENAISSANCE'),
		('TRAIT_LEADER_MAJOR_CIV',		'CULTURE_SCALING_INDUSTRIAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'CULTURE_SCALING_MODERN'),
		('TRAIT_LEADER_MAJOR_CIV',		'CULTURE_SCALING_ATOMIC'),
		('TRAIT_LEADER_MAJOR_CIV',		'CULTURE_SCALING_INFO'),
		('TRAIT_LEADER_MAJOR_CIV',		'CULTURE_SCALING_FUTURE'),
		('TRAIT_LEADER_MAJOR_CIV',		'FAITH_SCALING_CLASSICAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'FAITH_SCALING_MEDIEVAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'FAITH_SCALING_RENAISSANCE'),
		('TRAIT_LEADER_MAJOR_CIV',		'FAITH_SCALING_INDUSTRIAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'FAITH_SCALING_MODERN'),
		('TRAIT_LEADER_MAJOR_CIV',		'FAITH_SCALING_ATOMIC'),
		('TRAIT_LEADER_MAJOR_CIV',		'FAITH_SCALING_INFO'),
		('TRAIT_LEADER_MAJOR_CIV',		'FAITH_SCALING_FUTURE'),
		('TRAIT_LEADER_MAJOR_CIV',		'PRODUCTION_SCALING_CLASSICAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'PRODUCTION_SCALING_MEDIEVAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'PRODUCTION_SCALING_RENAISSANCE'),
		('TRAIT_LEADER_MAJOR_CIV',		'PRODUCTION_SCALING_INDUSTRIAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'PRODUCTION_SCALING_MODERN'),
		('TRAIT_LEADER_MAJOR_CIV',		'PRODUCTION_SCALING_ATOMIC'),
		('TRAIT_LEADER_MAJOR_CIV',		'PRODUCTION_SCALING_INFO'),
		('TRAIT_LEADER_MAJOR_CIV',		'PRODUCTION_SCALING_FUTURE'),
		('TRAIT_LEADER_MAJOR_CIV',		'GOLD_SCALING_CLASSICAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'GOLD_SCALING_MEDIEVAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'GOLD_SCALING_RENAISSANCE'),
		('TRAIT_LEADER_MAJOR_CIV',		'GOLD_SCALING_INDUSTRIAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'GOLD_SCALING_MODERN'),
		('TRAIT_LEADER_MAJOR_CIV',		'GOLD_SCALING_ATOMIC'),
		('TRAIT_LEADER_MAJOR_CIV',		'GOLD_SCALING_INFO'),
		('TRAIT_LEADER_MAJOR_CIV',		'GOLD_SCALING_FUTURE'),
		('TRAIT_LEADER_MAJOR_CIV',		'FOOD_SCALING_CLASSICAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'FOOD_SCALING_MEDIEVAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'FOOD_SCALING_RENAISSANCE'),
		('TRAIT_LEADER_MAJOR_CIV',		'FOOD_SCALING_INDUSTRIAL'),
		('TRAIT_LEADER_MAJOR_CIV',		'FOOD_SCALING_MODERN'),
		('TRAIT_LEADER_MAJOR_CIV',		'FOOD_SCALING_ATOMIC'),
		('TRAIT_LEADER_MAJOR_CIV',		'FOOD_SCALING_INFO'),
		('TRAIT_LEADER_MAJOR_CIV',		'FOOD_SCALING_FUTURE');

INSERT INTO ModifierArguments 
		(ModifierId,						Name,			Value) 
VALUES	('SCIENCE_SCALING_CLASSICAL',		'YieldType',	'YIELD_SCIENCE'),
		('SCIENCE_SCALING_MEDIEVAL',		'YieldType',	'YIELD_SCIENCE'),
		('SCIENCE_SCALING_RENAISSANCE',		'YieldType',	'YIELD_SCIENCE'),
		('SCIENCE_SCALING_INDUSTRIAL',		'YieldType',	'YIELD_SCIENCE'),
		('SCIENCE_SCALING_MODERN',			'YieldType',	'YIELD_SCIENCE'),
		('SCIENCE_SCALING_ATOMIC',			'YieldType',	'YIELD_SCIENCE'),
		('SCIENCE_SCALING_INFO',			'YieldType',	'YIELD_SCIENCE'),
		('SCIENCE_SCALING_FUTURE',			'YieldType',	'YIELD_SCIENCE'),
		('CULTURE_SCALING_CLASSICAL',		'YieldType',	'YIELD_CULTURE'),
		('CULTURE_SCALING_MEDIEVAL',		'YieldType',	'YIELD_CULTURE'),
		('CULTURE_SCALING_RENAISSANCE',		'YieldType',	'YIELD_CULTURE'),
		('CULTURE_SCALING_INDUSTRIAL',		'YieldType',	'YIELD_CULTURE'),
		('CULTURE_SCALING_MODERN',			'YieldType',	'YIELD_CULTURE'),
		('CULTURE_SCALING_ATOMIC',			'YieldType',	'YIELD_CULTURE'),
		('CULTURE_SCALING_INFO',			'YieldType',	'YIELD_CULTURE'),
		('CULTURE_SCALING_FUTURE',			'YieldType',	'YIELD_CULTURE'),
		('FAITH_SCALING_CLASSICAL',			'YieldType',	'YIELD_FAITH'),
		('FAITH_SCALING_MEDIEVAL',			'YieldType',	'YIELD_FAITH'),
		('FAITH_SCALING_RENAISSANCE',		'YieldType',	'YIELD_FAITH'),
		('FAITH_SCALING_INDUSTRIAL',		'YieldType',	'YIELD_FAITH'),
		('FAITH_SCALING_MODERN',			'YieldType',	'YIELD_FAITH'),
		('FAITH_SCALING_ATOMIC',			'YieldType',	'YIELD_FAITH'),
		('FAITH_SCALING_INFO',				'YieldType',	'YIELD_FAITH'),
		('FAITH_SCALING_FUTURE',			'YieldType',	'YIELD_FAITH'),
		('PRODUCTION_SCALING_CLASSICAL',	'YieldType',	'YIELD_PRODUCTION'),
		('PRODUCTION_SCALING_MEDIEVAL',		'YieldType',	'YIELD_PRODUCTION'),
		('PRODUCTION_SCALING_RENAISSANCE',	'YieldType',	'YIELD_PRODUCTION'),
		('PRODUCTION_SCALING_INDUSTRIAL',	'YieldType',	'YIELD_PRODUCTION'),
		('PRODUCTION_SCALING_MODERN',		'YieldType',	'YIELD_PRODUCTION'),
		('PRODUCTION_SCALING_ATOMIC',		'YieldType',	'YIELD_PRODUCTION'),
		('PRODUCTION_SCALING_INFO',			'YieldType',	'YIELD_PRODUCTION'),
		('PRODUCTION_SCALING_FUTURE',		'YieldType',	'YIELD_PRODUCTION'),
		('GOLD_SCALING_CLASSICAL',			'YieldType',	'YIELD_GOLD'),
		('GOLD_SCALING_MEDIEVAL',			'YieldType',	'YIELD_GOLD'),
		('GOLD_SCALING_RENAISSANCE',		'YieldType',	'YIELD_GOLD'),
		('GOLD_SCALING_INDUSTRIAL',			'YieldType',	'YIELD_GOLD'),
		('GOLD_SCALING_MODERN',				'YieldType',	'YIELD_GOLD'),
		('GOLD_SCALING_ATOMIC',				'YieldType',	'YIELD_GOLD'),
		('GOLD_SCALING_INFO',				'YieldType',	'YIELD_GOLD'),
		('GOLD_SCALING_FUTURE',				'YieldType',	'YIELD_GOLD'),
		('FOOD_SCALING_CLASSICAL',			'YieldType',	'YIELD_FOOD'),
		('FOOD_SCALING_MEDIEVAL',			'YieldType',	'YIELD_FOOD'),
		('FOOD_SCALING_RENAISSANCE',			'YieldType',	'YIELD_FOOD'),
		('FOOD_SCALING_INDUSTRIAL',			'YieldType',	'YIELD_FOOD'),
		('FOOD_SCALING_MODERN',				'YieldType',	'YIELD_FOOD'),
		('FOOD_SCALING_ATOMIC',				'YieldType',	'YIELD_FOOD'),
		('FOOD_SCALING_INFO',				'YieldType',	'YIELD_FOOD'),
		('FOOD_SCALING_FUTURE',				'YieldType',	'YIELD_FOOD');

INSERT INTO ModifierArguments 
		(ModifierId,						Name,		Type,								Value,	Extra) 
VALUES		('AMENITY_SCALING_CLASSICAL', 'Amount', 'LinearScaleFromDefaultHandicap', 	0, 0),
		('AMENITY_SCALING_MEDIEVAL', 'Amount', 'LinearScaleFromDefaultHandicap', 	0, 0.5),
		('AMENITY_SCALING_RENAISSANCE', 'Amount', 'LinearScaleFromDefaultHandicap', 	0, 0),
		('AMENITY_SCALING_INDUSTRIAL', 'Amount', 'LinearScaleFromDefaultHandicap', 	0, 0.5),
		('AMENITY_SCALING_MODERN', 'Amount', 'LinearScaleFromDefaultHandicap', 		0, 0),
		('AMENITY_SCALING_ATOMIC', 'Amount', 'LinearScaleFromDefaultHandicap', 		0, 0.5),
		('AMENITY_SCALING_INFO', 'Amount', 'LinearScaleFromDefaultHandicap', 		0, 0),
		('AMENITY_SCALING_FUTURE', 'Amount', 'LinearScaleFromDefaultHandicap', 		0, 0.5),
		('TOURISM_SCALING_CLASSICAL', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 0),
		('TOURISM_SCALING_MEDIEVAL', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 13),
		('TOURISM_SCALING_RENAISSANCE', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 26),
		('TOURISM_SCALING_INDUSTRIAL', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 39),
		('TOURISM_SCALING_MODERN', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 52),
		('TOURISM_SCALING_ATOMIC', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 65),
		('TOURISM_SCALING_INFO', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 78),
		('TOURISM_SCALING_FUTURE', 'Amount', 'LinearScaleFromDefaultHandicap', 0, 91),
		('SCIENCE_SCALING_CLASSICAL',		'Amount',	'LinearScaleFromDefaultHandicap',	0,		2),
		('SCIENCE_SCALING_MEDIEVAL',		'Amount',	'LinearScaleFromDefaultHandicap',	0,		4),
		('SCIENCE_SCALING_RENAISSANCE',		'Amount',	'LinearScaleFromDefaultHandicap',	0,		6),
		('SCIENCE_SCALING_INDUSTRIAL',		'Amount',	'LinearScaleFromDefaultHandicap',	0,		8),
		('SCIENCE_SCALING_MODERN',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		10),
		('SCIENCE_SCALING_ATOMIC',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		12),
		('SCIENCE_SCALING_INFO',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		14),
		('SCIENCE_SCALING_FUTURE',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		16),
		('CULTURE_SCALING_CLASSICAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		2),
		('CULTURE_SCALING_MEDIEVAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		4),
		('CULTURE_SCALING_RENAISSANCE',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		6),
		('CULTURE_SCALING_INDUSTRIAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		8),
		('CULTURE_SCALING_MODERN',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		10),
		('CULTURE_SCALING_ATOMIC',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		12),
		('CULTURE_SCALING_INFO',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		14),
		('CULTURE_SCALING_FUTURE',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		16),

--these do nothing for now, just leaving them in so saves don't get ruined somehow when I just delete them (new bonuses are below)
		('FAITH_SCALING_CLASSICAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('FAITH_SCALING_MEDIEVAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('FAITH_SCALING_RENAISSANCE',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('FAITH_SCALING_INDUSTRIAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('FAITH_SCALING_MODERN',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('FAITH_SCALING_ATOMIC',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('FAITH_SCALING_INFO',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('FAITH_SCALING_FUTURE',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('PRODUCTION_SCALING_CLASSICAL',		'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('PRODUCTION_SCALING_MEDIEVAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('PRODUCTION_SCALING_RENAISSANCE',		'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('PRODUCTION_SCALING_INDUSTRIAL',		'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('PRODUCTION_SCALING_MODERN',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('PRODUCTION_SCALING_ATOMIC',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('PRODUCTION_SCALING_INFO',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('PRODUCTION_SCALING_FUTURE',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('GOLD_SCALING_CLASSICAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('GOLD_SCALING_MEDIEVAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('GOLD_SCALING_RENAISSANCE',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('GOLD_SCALING_INDUSTRIAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('GOLD_SCALING_MODERN',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('GOLD_SCALING_ATOMIC',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('GOLD_SCALING_INFO',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),
		('GOLD_SCALING_FUTURE',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		0),

		('FOOD_SCALING_CLASSICAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		1),
		('FOOD_SCALING_MEDIEVAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		1),
		('FOOD_SCALING_RENAISSANCE',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		1),
		('FOOD_SCALING_INDUSTRIAL',			'Amount',	'LinearScaleFromDefaultHandicap',	0,		1),
		('FOOD_SCALING_MODERN',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		1),
		('FOOD_SCALING_ATOMIC',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		1),
		('FOOD_SCALING_INFO',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		1),
		('FOOD_SCALING_FUTURE',				'Amount',	'LinearScaleFromDefaultHandicap',	0,		1);

--production, faith and gold bonus of 1% per difficulty and civic
INSERT INTO Modifiers(ModifierId, ModifierType, OwnerRequirementSetId)
    SELECT 'LGAI_PRODUCTION_' || CivicType, 'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER', 'LGAI_PLAYER_HAS_' || CivicType
    FROM Civics;
INSERT INTO ModifierArguments(ModifierId, Name, Value)
    SELECT 'LGAI_PRODUCTION_' || CivicType, 'YieldType', 'YIELD_PRODUCTION'
    FROM Civics;
INSERT INTO ModifierArguments(ModifierId, Name, Type, Value, Extra)
    SELECT 'LGAI_PRODUCTION_' || CivicType, 'Amount', 'LinearScaleFromDefaultHandicap', '0', '1'
    FROM Civics;
INSERT INTO TraitModifiers(TraitType, ModifierId)
    SELECT 'TRAIT_LEADER_MAJOR_CIV', 'LGAI_PRODUCTION_' || CivicType
    FROM Civics;

INSERT INTO Modifiers(ModifierId, ModifierType, OwnerRequirementSetId)
    SELECT 'LGAI_GOLD_' || CivicType, 'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER', 'LGAI_PLAYER_HAS_' || CivicType
    FROM Civics;
INSERT INTO ModifierArguments(ModifierId, Name, Value)
    SELECT 'LGAI_GOLD_' || CivicType, 'YieldType', 'YIELD_GOLD'
    FROM Civics;
INSERT INTO ModifierArguments(ModifierId, Name, Type, Value, Extra)
    SELECT 'LGAI_GOLD_' || CivicType, 'Amount', 'LinearScaleFromDefaultHandicap', '0', '1'
    FROM Civics;
INSERT INTO TraitModifiers(TraitType, ModifierId)
    SELECT 'TRAIT_LEADER_MAJOR_CIV', 'LGAI_GOLD_' || CivicType
    FROM Civics;

INSERT INTO Modifiers(ModifierId, ModifierType, OwnerRequirementSetId)
    SELECT 'LGAI_FAITH_' || CivicType, 'MODIFIER_PLAYER_CITIES_ADJUST_CITY_YIELD_MODIFIER', 'LGAI_PLAYER_HAS_' || CivicType
    FROM Civics;
INSERT INTO ModifierArguments(ModifierId, Name, Value)
    SELECT 'LGAI_FAITH_' || CivicType, 'YieldType', 'YIELD_FAITH'
    FROM Civics;
INSERT INTO ModifierArguments(ModifierId, Name, Type, Value, Extra)
    SELECT 'LGAI_FAITH_' || CivicType, 'Amount', 'LinearScaleFromDefaultHandicap', '0', '1'
    FROM Civics;
INSERT INTO TraitModifiers(TraitType, ModifierId)
    SELECT 'TRAIT_LEADER_MAJOR_CIV', 'LGAI_FAITH_' || CivicType
    FROM Civics;